==> jc-1.4.0.tar.gz: java/io/FileWriter.h <==
// public class java.io.FileWriter

// class file dependencies
// @dep_class 3c8cbb55c7a97310 java_io_FileWriter
// @dep_class 2b7018cc9ffb0f80 java_io_OutputStreamWriter
// @dep_class 4897ee169f60a14f java_io_Writer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_OutputStreamWriter

#include "java/io/OutputStreamWriter.h"

#ifndef _JC_java_io_FileWriter_H_
#define _JC_java_io_FileWriter_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_FileDescriptor$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_FileWriter$sub_refs	_jc_java_io_FileWriter$sub_refs;
typedef struct _jc_java_io_FileWriter$sub_nonrefs	_jc_java_io_FileWriter$sub_nonrefs;
typedef struct _jc_java_io_FileWriter$refs	_jc_java_io_FileWriter$refs;
typedef struct _jc_java_io_FileWriter$nonrefs	_jc_java_io_FileWriter$nonrefs;
typedef struct _jc_java_io_FileWriter$object	_jc_java_io_FileWriter$object;

typedef const struct _jc_java_io_FileWriter$vmethods	_jc_java_io_FileWriter$vmethods;
typedef const struct _jc_java_io_FileWriter$vtable	_jc_java_io_FileWriter$vtable;
typedef const struct _jc_java_io_FileWriter$vtype	_jc_java_io_FileWriter$vtype;

// Constructors
extern void _jc_java_io_FileWriter$method$_init$538ee07130435a5e(_jc_env *, struct _jc_java_io_FileWriter$object *, struct _jc_java_io_File$object *);
extern void _jc_java_io_FileWriter$method$_init$1a55b883867a95b8(_jc_env *, struct _jc_java_io_FileWriter$object *, struct _jc_java_io_File$object *, jboolean);
extern void _jc_java_io_FileWriter$method$_init$0c8bd339d1fd1424(_jc_env *, struct _jc_java_io_FileWriter$object *, struct _jc_java_io_FileDescriptor$object *);
extern void _jc_java_io_FileWriter$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_io_FileWriter$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_io_FileWriter$method$_init$73d32b75516f7b43(_jc_env *, struct _jc_java_io_FileWriter$object *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_java_io_FileWriter$vmethods {
};

// Vtable
struct _jc_java_io_FileWriter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Writer$vmethods	java_io_Writer;
	_jc_java_io_OutputStreamWriter$vmethods	java_io_OutputStreamWriter;
	_jc_java_io_FileWriter$vmethods	java_io_FileWriter;
};

// Vtype
struct _jc_java_io_FileWriter$vtype {
	_jc_type			type;
	_jc_java_io_FileWriter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_FileWriter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_FileWriter$refs {
    _jc_java_io_FileWriter$sub_refs	java_io_FileWriter;
    _jc_java_io_OutputStreamWriter$sub_refs	java_io_OutputStreamWriter;
    _jc_java_io_Writer$sub_refs	java_io_Writer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_FileWriter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_FileWriter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Writer$sub_nonrefs	java_io_Writer;
    _jc_java_io_OutputStreamWriter$sub_nonrefs	java_io_OutputStreamWriter;
    _jc_java_io_FileWriter$sub_nonrefs	java_io_FileWriter;
};

// Object instance structure
struct _jc_java_io_FileWriter$object {
	_jc_java_io_FileWriter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_FileWriter$vtype	*vtype;
	_jc_java_io_FileWriter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_FileWriter$vtype _jc_java_io_FileWriter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_FileWriter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_FileWriter$class_object;

#endif	/* _JC_java_io_FileWriter_H_ */

==> jc-1.4.6.tar.gz: java/io/FileWriter.h <==
// public class java.io.FileWriter

// class file dependencies
// @dep_class 3c8cbb55c7a97310 java_io_FileWriter
// @dep_class b2c3042960814a35 java_io_OutputStreamWriter
// @dep_class 4897ee169f60a14f java_io_Writer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_OutputStreamWriter

#include "java/io/OutputStreamWriter.h"

#ifndef _JC_java_io_FileWriter_H_
#define _JC_java_io_FileWriter_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_FileDescriptor$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_FileWriter$sub_refs	_jc_java_io_FileWriter$sub_refs;
typedef struct _jc_java_io_FileWriter$sub_nonrefs	_jc_java_io_FileWriter$sub_nonrefs;
typedef struct _jc_java_io_FileWriter$refs	_jc_java_io_FileWriter$refs;
typedef struct _jc_java_io_FileWriter$nonrefs	_jc_java_io_FileWriter$nonrefs;
typedef struct _jc_java_io_FileWriter$object	_jc_java_io_FileWriter$object;

typedef const struct _jc_java_io_FileWriter$vmethods	_jc_java_io_FileWriter$vmethods;
typedef const struct _jc_java_io_FileWriter$vtable	_jc_java_io_FileWriter$vtable;
typedef const struct _jc_java_io_FileWriter$vtype	_jc_java_io_FileWriter$vtype;

// Constructors
extern void _jc_java_io_FileWriter$method$_init$538ee07130435a5e(_jc_env *, struct _jc_java_io_FileWriter$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_FileWriter$method$_init$1a55b883867a95b8(_jc_env *, struct _jc_java_io_FileWriter$object *, struct _jc_java_io_File$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_java_io_FileWriter$method$_init$0c8bd339d1fd1424(_jc_env *, struct _jc_java_io_FileWriter$object *, struct _jc_java_io_FileDescriptor$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_FileWriter$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_io_FileWriter$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_FileWriter$method$_init$73d32b75516f7b43(_jc_env *, struct _jc_java_io_FileWriter$object *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_io_FileWriter$vmethods {
};

// Vtable
struct _jc_java_io_FileWriter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Writer$vmethods	java_io_Writer;
	_jc_java_io_OutputStreamWriter$vmethods	java_io_OutputStreamWriter;
	_jc_java_io_FileWriter$vmethods	java_io_FileWriter;
};

// Vtype
struct _jc_java_io_FileWriter$vtype {
	_jc_type			type;
	_jc_java_io_FileWriter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_FileWriter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_FileWriter$refs {
    _jc_java_io_FileWriter$sub_refs	java_io_FileWriter;
    _jc_java_io_OutputStreamWriter$sub_refs	java_io_OutputStreamWriter;
    _jc_java_io_Writer$sub_refs	java_io_Writer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_FileWriter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_FileWriter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Writer$sub_nonrefs	java_io_Writer;
    _jc_java_io_OutputStreamWriter$sub_nonrefs	java_io_OutputStreamWriter;
    _jc_java_io_FileWriter$sub_nonrefs	java_io_FileWriter;
};

// Object instance structure
struct _jc_java_io_FileWriter$object {
	_jc_java_io_FileWriter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_FileWriter$vtype	*vtype;
	_jc_java_io_FileWriter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_FileWriter$vtype _jc_java_io_FileWriter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_FileWriter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_FileWriter$class_object;

#endif	/* _JC_java_io_FileWriter_H_ */
